@@ -7,7 +7,8 @@ def find_style_change_starts_by_ac(feature_vectors, hyperparams):
     n_clusters = 3 if not hyperparams else hyperparams[0]
     affinity = 'euclidean' if not hyperparams else hyperparams[1]
     linkage = 'ward' if not hyperparams else hyperparams[2]
-
+    if len(feature_vectors) <= n_clusters:
+        return [index for index in range(len(feature_vectors))]
     model = AgglomerativeClustering(n_clusters=n_clusters, affinity=affinity, linkage=linkage)
     clusters = model.fit_predict(feature_vectors)
     sorted_clusters = Counter(clusters).most_common()
